@@ -2,56 +2,68 @@
 # -*- coding: utf-8 -*-
 
 from holmes.validators.base import Validator
+from holmes.utils import _
 
 
 class JSRequestsValidator(Validator):
-    @classmethod
-    def get_requests_js_message(cls, value):
-        return 'This page has %d JavaScript request ' \
-               '(%d over limit). Having too many requests impose ' \
-               'a tax in the browser due to handshakes.' % (
-                   value['total_js_files'],
-                   value['over_limit'])
-
-    @classmethod
-    def get_total_size_message(cls, value):
-        return 'There\'s %.2fkb of JavaScript in this page and ' \
-               'that adds up to more download time slowing down ' \
-               'the page rendering to the user.' % value
 
     @classmethod
     def get_violation_definitions(cls):
         return {
             'total.requests.js': {
-                'title': 'Too many JavaScript requests',
-                'description': cls.get_requests_js_message,
-                'category': 'Performance',
-                'generic_description': (
+                'title': _('Too many JavaScript requests'),
+                'description': _(
+                    'This page has %(total_js_files)d JavaScript request '
+                    '(%(over_limit)d over limit). Having too many requests '
+                    'impose a tax in the browser due to handshakes.'),
+                'category': _('Performance'),
+                'generic_description': _(
                     'A site with too many JavaScript requests per page can '
                     'deacrease the page load speed and performance. This '
                     'limits are configurable in Holmes configuration.'
-                )
+                ),
+                'unit': 'number'
             },
             'total.size.js': {
-                'title': 'JavaScript size in kb is too big',
-                'description': cls.get_total_size_message,
-                'category': 'Performance',
-                'generic_description': (
+                'title': _('JavaScript size in kb is too big'),
+                'description': _(
+                    'There\'s %.2fkb of JavaScript in this page and '
+                    'that adds up to more download time slowing down '
+                    'the page rendering to the user.'),
+                'category': _('Performance'),
+                'generic_description': _(
                     'A site with a too big total JavaScript size per page can '
                     'decrease the page load speed and performance. This '
                     'limits are configurable in Holmes configuration.'
-                )
+                ),
+                'unit': 'number'
+            }
+        }
+
+    @classmethod
+    def get_default_violations_values(cls, config):
+        return {
+            'total.size.js': {
+                'value': config.MAX_JS_KB_PER_PAGE_AFTER_GZIP,
+                'description': config.get_description('MAX_JS_KB_PER_PAGE_AFTER_GZIP')
+            },
+            'total.requests.js': {
+                'value': config.MAX_JS_REQUESTS_PER_PAGE,
+                'description': config.get_description('MAX_JS_REQUESTS_PER_PAGE')
             }
         }
 
     def validate(self):
+        max_size_js = self.get_violation_pref('total.size.js')
+
+        max_requests_js = self.get_violation_pref('total.requests.js')
+
         total_js_files = self.get_total_requests_js()
         total_size_gzip = self.get_total_size_js_gzipped()
 
-        max_requests = self.reviewer.config.MAX_JS_REQUESTS_PER_PAGE
-        over_limit = total_js_files - max_requests
+        over_limit = total_js_files - max_requests_js
 
-        if total_js_files > max_requests:
+        if total_js_files > max_requests_js:
             self.add_violation(
                 key='total.requests.js',
                 value={
@@ -60,13 +72,11 @@ class JSRequestsValidator(Validator):
                 points=5 * over_limit
             )
 
-        max_kb_gzip = self.reviewer.config.MAX_JS_KB_PER_PAGE_AFTER_GZIP
-
-        if total_size_gzip > max_kb_gzip:
+        if total_size_gzip > max_size_js:
             self.add_violation(
                 key='total.size.js',
                 value=total_size_gzip,
-                points=int(total_size_gzip - max_kb_gzip)
+                points=int(total_size_gzip - max_size_js)
             )
 
     def get_js_requests(self):
